==> haskell-asn1-types-0.3.4-258-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-asn1-types.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 asn1-types
version:              0.3.4
visibility:           public
id:                   asn1-types-0.3.4-3loQto5LRBpFKUk7N5Cpk7
key:                  asn1-types-0.3.4-3loQto5LRBpFKUk7N5Cpk7
license:              BSD-3-Clause
copyright:            Vincent Hanquez <vincent@snarc.org>
maintainer:           Vincent Hanquez <vincent@snarc.org>
author:               Vincent Hanquez <vincent@snarc.org>
stability:            experimental
homepage:             http://github.com/vincenthz/hs-asn1
synopsis:             ASN.1 types
description:          ASN.1 standard types
category:             Data
abi:                  60c10577240085f0a3b52ca5c0cbe3af
exposed:              True
exposed-modules:
    Data.ASN1.BitArray Data.ASN1.OID Data.ASN1.Pretty Data.ASN1.Types
    Data.ASN1.Types.Lowlevel Data.ASN1.Types.String

import-dirs:          /usr/lib/ghc-9.4.8/site-local/asn1-types-0.3.4
library-dirs:         /usr/lib/ghc-9.4.8/site-local/asn1-types-0.3.4
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/asn1-types-0.3.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-asn1-types
hs-libraries:         HSasn1-types-0.3.4-3loQto5LRBpFKUk7N5Cpk7
depends:
    base-4.17.2.1 bytestring-0.11.5.3
    hourglass-0.2.12-CntI9UQk4VpJlgia8F0Px7
    memory-0.18.0-1oHOZXUPjWrG0kImkORGvt

haddock-interfaces:   /usr/share/doc/haskell-asn1-types/html/asn1-types.haddock
haddock-html:         /usr/share/doc/haskell-asn1-types/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-asn1-types-0.3.4-259-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-asn1-types.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 asn1-types
version:              0.3.4
visibility:           public
id:                   asn1-types-0.3.4-Gla04HcvDO18FBY9rV7iXP
key:                  asn1-types-0.3.4-Gla04HcvDO18FBY9rV7iXP
license:              BSD-3-Clause
copyright:            Vincent Hanquez <vincent@snarc.org>
maintainer:           Vincent Hanquez <vincent@snarc.org>
author:               Vincent Hanquez <vincent@snarc.org>
stability:            experimental
homepage:             http://github.com/vincenthz/hs-asn1
synopsis:             ASN.1 types
description:          ASN.1 standard types
category:             Data
abi:                  ae405a62e3d4fd719f1eef1a3c298216
exposed:              True
exposed-modules:
    Data.ASN1.BitArray Data.ASN1.OID Data.ASN1.Pretty Data.ASN1.Types
    Data.ASN1.Types.Lowlevel Data.ASN1.Types.String

import-dirs:          /usr/lib/ghc-9.4.8/site-local/asn1-types-0.3.4
library-dirs:         /usr/lib/ghc-9.4.8/site-local/asn1-types-0.3.4
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/asn1-types-0.3.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-asn1-types
hs-libraries:         HSasn1-types-0.3.4-Gla04HcvDO18FBY9rV7iXP
depends:
    base-4.17.2.1 bytestring-0.11.5.3
    hourglass-0.2.12-7KFeZE6j4iLAuc8KMyy8fY
    memory-0.18.0-1oHOZXUPjWrG0kImkORGvt

haddock-interfaces:   /usr/share/doc/haskell-asn1-types/html/asn1-types.haddock
haddock-html:         /usr/share/doc/haskell-asn1-types/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
